import React from 'react';
import { View, Text, FlatList, Button } from 'react-native';
import { useNavigation } from '@react-navigation/native';

const itemsInBasket = [
  { id: 1, name: 'Product 1', price: 10.0 },
  { id: 2, name: 'Product 2', price: 20.0 },
  { id: 3, name: 'Product 3', price: 15.0 },
];

function BasketScreen() {
  const navigation = useNavigation();

  const calculateTotalPrice = () => {
    return itemsInBasket.reduce((total, item) => total + item.price, 0).toFixed(2);
  };

  const renderItem = ({ item }) => (
    <View style={{ flexDirection: 'row', justifyContent: 'space-between', padding: 10 }}>
      <Text>{item.name}</Text>
      <Text>${item.price.toFixed(2)}</Text>
    </View>
  );

  return (
    <View style={{ flex: 1, padding: 16 }}>
      <Text style={{ fontSize: 20, fontWeight: 'bold', marginBottom: 16 }}>Basket</Text>
      <FlatList
        data={itemsInBasket}
        renderItem={renderItem}
        keyExtractor={(item) => item.id.toString()}
      />
      <View style={{ flexDirection: 'row', justifyContent: 'space-between', marginTop: 16 }}>
        <Text style={{ fontSize: 16 }}>Total:</Text>
        <Text style={{ fontSize: 16 }}>${calculateTotalPrice()}</Text>
      </View>
      <Button
          title="Pay"
          onPress={() => navigation.navigate('Checkout', { totalPrice: calculateTotalPrice() })}
      />

    </View>
  );
}

export default BasketScreen;
